//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithoutGot](index.md)/[goodShapeImprovementNum](good-shape-improvement-num.md)

# goodShapeImprovementNum

[common]\

@EncodeDefault

val [goodShapeImprovementNum](good-shape-improvement-num.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)?

好型改良张数（能让听牌数目增加到大于4张的牌） 仅当听牌时进行计算
